@@ -37,11 +37,11 @@ __all__ = [
 
 
 message_attributes = (
-    'sender',
     'received_by',
     'received_from',
     'received_with',
-    'recipient'
+    'recipient',
+    'sender',
 )
 
 _NL = os.linesep.encode()
@@ -85,12 +85,11 @@ class Message(object):
     __slots__ = (
         '__msg',
         '__raw',
-        #'log',
-        'sender',
         'received_by',
         'received_from',
         'received_with',
         'recipient',
+        'sender',
     )
     def __init__(self, fromlines=None, fromstring=None, fromfile=None):
         #self.log = Logger()
@@ -209,8 +208,6 @@ class Message(object):
             return ((fromline+rpline+dtline+rcvline).encode('ASCII',errors="replace")+bmsg)
 
         except (TypeError,UnicodeEncodeError) as o:
-            # email module chokes on some badly-misformatted messages, even
-            # late during flatten().  Hope this is fixed in Python 2.4.
             if self.__raw is None:
                 # Argh -- a filter took a correctly-formatted message
                 # and returned a badly-misformatted one?
